package com.java24hours.banko;

import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.net.*;
import java.util.*;
import javax.swing.*;

public class Banko3 extends JApplet implements ActionListener {
    // the money inside a money bag
    public int reward = 500;
    // the cost of opening an empty bag
    public int cost = 250;
    // the size of the game board and total number of money bags
    public int row_count = 3;
    public int column_count = 10;
    public int bag_count = 10;
    // the fields that report how a player’s doing
    private JTextField moneyField;
    private JTextField foundField;
    // the restart button
    public JButton restart;
    // a player’s money and the number of money bags found
    public int money;
    public int found;
    // the game board
    private Board3 board;

    // create the applet
    public void init() {
        // set its layout manager
        BorderLayout border = new BorderLayout();
        setLayout(border);

        // create the top panel
        JPanel top = new JPanel();
        // create the "Money:" label and text field
        JLabel moneyLabel = new JLabel("Money: $");
        moneyField = new JTextField("", 8);
        // prevent it from being edited
        moneyField.setEditable(false);
        // create the "Found:" label and text field
        JLabel foundLabel = new JLabel("Found: ");
        foundField = new JTextField("", 8);
        foundField.setEditable(false);
        // create the Restart button
        restart = new JButton("Restart");
        // assign the applet to monitor clicks of this button
        restart.addActionListener(this);
        // add the components to the top panel
        top.add(moneyLabel);
        top.add(moneyField);
        top.add(foundLabel);
        top.add(foundField);
        top.add(restart);
        // add the panel to the border’s topmost position
        add(top, BorderLayout.NORTH);

        // load the game properties
        try {
            File propFile = new File("Banko3.properties");
            FileInputStream propStream = new FileInputStream(propFile);
            Properties props = new Properties();
            props.load(propStream);
            this.row_count = Integer.parseInt(props.getProperty("rows"));
            this.column_count = Integer.parseInt(props.getProperty("columns"));
            this.bag_count = Integer.parseInt(props.getProperty("bags"));
            this.cost = Integer.parseInt(props.getProperty("cost"));
            this.reward = Integer.parseInt(props.getProperty("reward"));
        } catch (IOException ioe) {
            // do nothing; use defaults
        }

        // create the game board
        board = new Board3(this, row_count, column_count, bag_count);
        // add the board to the border’s center position
        add(board, BorderLayout.CENTER);
        // set up the applet
        setup();
        // display the user interface
        setVisible(true);
    }

    // set up the applet for gameplay
    public void setup() {
        found = -1;
        money = 0;
        // give the player starting money
        earnMoney();
    }

    // take money from the player for opening an empty bag
    public void spendMoney() {
        // deduct funds and display the new total
        money = money - cost;
        moneyField.setText("" + money);
        if (money <= 0) {
            // the player’s broke, so end the game
            revealBoard();
        }
    }

    // award money to the player for finding a money bag
    public void earnMoney() {
        // add funds and display the total
        money = money + reward;
        moneyField.setText("" + money);
        // count the newly found bag
        found++;
        foundField.setText("" + found + " of " + bag_count);
        if (found >= bag_count) {
            // the player’s found all bags, so end the game
            revealBoard();
        }
    }

    // reveal the entire board at game’s end
    public void revealBoard() {
        // inspect every square on the board
        for (int row = 0; row < row_count; row++) {
            for (int column = 0; column < column_count; column++) {
                // get the current button
                Button3 button = board.square[row][column];
                if (button.state == -2) {
                    // display this money bag
                    button.found = true;
                    button.revealMoney();
                } else {
                    // set up happy and sad colors
                    Color green = new Color(204, 255, 204);
                    Color red = new Color(255, 204, 204);
                    if (money > 0) {
                        // player won, so make this empty square green
                        button.setBackground(green);
                    } else {
                        // player lost, so make this empty square red
                        button.setBackground(red);
                    }
                }
                if (button.state == 0) {
                    // this square has never been cleared, so do so now
                    button.clear(false);
                }
            }
        }
    }

    // load a button graphic using the applet’s codebase as a base URL
    public ImageIcon getImageIcon(String filename) {
        ImageIcon icon = null;
        try {
            // build a URL using the codebase and the graphic’s filename
            URL url = new URL(getCodeBase(), filename);
            // load an image icon from that URL
            icon = new ImageIcon(url);
        } catch (java.net.MalformedURLException exception) {
            // report an error because the URL isn’t valid
            System.out.println(exception.getMessage());
            return null;
        }
        return icon;
    }

    // monitor button clicks on the game board and restart button
    public void actionPerformed(ActionEvent event) {
        // determine the button the player clicked
        Object source = event.getSource();
        if (source instanceof Button3) {
            // the button’s on the game board
            Button3 button = (Button3) event.getSource();
            if (button.state == -2) {
                // it contains a money bag, so reveal it
                button.revealMoney();
            } else {
                // it doesn’t contain a money bag, so clear it
                button.clear(true);
            }
        } else {
            // the restart button was clicked
            // set up the applet anew
            setup();
            // set up the board too
            board.setup();
        }
    }
}